@@ -23,7 +23,7 @@
 
 Resource::Resource(const char *dataPath, Version ver) {
 	memset(this, 0, sizeof(Resource));
-	_dataPath = "/opt/flashback/data";
+	_dataPath = "/home/user/MyDocs/.flashback";
 	_ver = ver;
 	_memBuf = (uint8 *)malloc(0xE000);
 }
